@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
+from admin_interface.models import Theme
+
 from django.contrib import admin
 from django.utils.translation import ugettext_lazy as _
 
-from admin_interface.models import Theme
-
 
 class ThemeAdmin(admin.ModelAdmin):
 
@@ -27,6 +27,13 @@ class ThemeAdmin(admin.ModelAdmin):
                 'env_visible_in_favicon',
             )
         }),
+        (_('Language chooser'), {
+            'classes': ('wide', ),
+            'fields': (
+                'language_chooser_active',
+                'language_chooser_display',
+            )
+        }),
         (_('Logo'), {
             'classes': ('wide', ),
             'fields': (
